****************
MongoDB workflow
****************

It display workflow in MongoDB point of view. Please run inside console ::

  mongo
  use sfchat

.. toctree::
   :maxdepth: 2
   :titlesonly:

   Create chat
   Authorization
   Join chat by code
   Conversation long-polling   
